"""Scapy Manager package."""

from .core.worker import Worker
